mysql.exceptions.client

Package mysql :: Package exceptions :: Module client |
[hide private]
[frames] | no frames]

# Module client

source code

Exceptions from the MySQL client API.

These are all errors that the client-side of the MySQL API may generate.

Classes | [hide private]
`` | Unknown_Error An unknown error occurred.
`` | Socket_Create_Error Failed to create a Unix socket.
`` | Connection_Error Failed to connect to the local MySQL server.
`` | Conn_Host_Error Failed to connect to the MySQL server.
`` | IP_Sock_Error Failed to create an IP socket.
`` | Unknown_Host Failed to find the IP address for the hostname.
`` | Server_Gone_Error MySQL server has gone away.
`` | Version_Error A protocol mismatch resulted from attempting to connect to a server with a client library that uses a different protocol version.
`` | Out_Of_Memory MySQL client ran out of memory.
`` | Wrong_Host_Info Wrong host info.
`` | Localhost_Connection Localhost via UNIX socket.
`` | TCP_Connection TCP connection error.
`` | Server_Handshake_Err Error in server handshake.
`` | Server_Lost If connect_timeout > 0 and it took longer than connect_timeout seconds to connect to the server or if the server died while executing the init-command.
`` | Commands_Out_Of_Sync Commands out of sync; you can't run this command now.
`` | Named_Pipe_Connection Failed to connect to a named pipe on Windows.
`` | Named_Pipe_Wait_Error Failed to wait for a named pipe on Windows.
`` | Named_Pipe_Open_Error Failed to create a named pipe on Windows.
`` | Named_Pipe_Set_State_Error Failed to get a pipe handler on Windows.
`` | Cant_Read_Charset Unable to read the character set file.
`` | Net_Packet_Too_Large Got packet bigger than 'max_allowed_packet' bytes.
`` | Embedded_Connection Embedded server.
`` | Probe_Slave_Status Error on SHOW SLAVE STATUS:.
`` | Probe_Slave_Hosts Error on SHOW SLAVE HOSTS:.
`` | Probe_Slave_Connect Error connecting to slave:.
`` | Probe_Master_Connect Error connecting to master:.
`` | Ssl_Connection_Error SSL connection error.
`` | Malformed_Packet Malformed packet.
`` | Wrong_License Invalid license when connecting to server.
`` | Null_Pointer Invalid use of null pointer.
`` | No_Prepare_Stmt Statement not prepared.
`` | Params_Not_Bound No data supplied for parameters in prepared statement.
`` | Data_Truncated Data truncated.
`` | No_Parameters_Exists No parameters exist in the statement.
`` | Invalid_Parameter_Number Invalid parameter number.
`` | Invalid_Buffer_Use Indicates if the bind is to supply the long data in chunks and if the buffer type is non string or binary.
`` | Unsupported_Param_Type The conversion is not supported.
`` | Shared_Memory_Connection Connection failure when using shared memory.
`` | Shared_Memory_Connect_Request_Error Can't open shared memory; client could not create request event.
`` | Shared_Memory_Connect_Answer_Error Can't open shared memory; no answer event received from server.
`` | Shared_Memory_Connect_File_Map_Error Can't open shared memory; server could not allocate file mapping.
`` | Shared_Memory_Connect_Map_Error Can't open shared memory; server could not get pointer to file mapping.
`` | Shared_Memory_File_Map_Error Can't open shared memory; client could not allocate file mapping.
`` | Shared_Memory_Map_Error Can't open shared memory; client could not get pointer to file mapping.
`` | Shared_Memory_Event_Error Can't open shared memory; client could not create an event.
`` | Shared_Memory_Connect_Abandoned_Error Can't open shared memory; no answer from server.
`` | Shared_Memory_Connect_Set_Error Can't open shared memory; cannot send request event to server.
`` | Conn_Unknow_Protocol Wrong or unknown protocol.
`` | Invalid_Conn_Handle Invalid connection handle.
`` | Secure_Auth Connection using old (pre-4.1.1) authentication protocol refused (client option 'secure_auth' enabled).
`` | Fetch_Canceled Row retrieval was canceled by mysql_stmt_close() call.
`` | No_Data Attempt to read column without prior row fetch.
`` | No_Stmt_Metadata Prepared statement contains no metadata.
`` | No_Result_Set Attempt to read a row while there is no result set associated with the statement.
`` | Not_Implemented This feature is not implemented yet.

Variables | [hide private]
`` | __version__ = `'$Revision: 1.3 $'`

Variables Details | [hide private]

    ### __version__ Value:
        '$Revision: 1.3 $'